@@ -1,16 +1,19 @@
 test_that("all course packages are listed with version and whether attached", {
-  # use these packages because they are not imported
-  # they need to be in the order they appear in the coursekata_pkgs object
+  # these packages are not imported, but are still in the load out
+  # (important because they can be detached and re-attached during testing)
   pkgs <- c("fivethirtyeightdata", "fivethirtyeight")
-  # fivethirtyeightdata is not always installed, and if so, it won't get attached
-  # detach/re-attach only if it is installed
+
+  # they need to be in the order they appear in the coursekata_pkgs object
+  pkgs <- pkgs[order(match(pkgs, coursekata_pkgs))]
+
+  # detach/re-attach only installed packages
   installed <- pkg_is_installed(pkgs)
+  names(installed) <- pkgs
   detacher(pkgs[installed])
   withr::defer(attacher(pkgs[installed]))
 
   # only the installed package will be attached
   attachments <- coursekata_attach(quietly = TRUE)
-  names(installed) <- pkgs
   expect_identical(attachments, installed)
 })
 
